@@ -175,6 +175,7 @@ anjuta_util_button_new_with_stock_image (const gchar* text,
 										 const gchar* stock_id)
 {
 	GtkWidget *button;
+	GtkWidget *child;
 	GtkStockItem item;
 	GtkWidget *label;
 	GtkWidget *image;
@@ -183,9 +184,9 @@ anjuta_util_button_new_with_stock_image (const gchar* text,
 
 	button = gtk_button_new ();
 
- 	if (GTK_BIN (button)->child)
-    		gtk_container_remove (GTK_CONTAINER (button),
-				      GTK_BIN (button)->child);
+	child = gtk_bin_get_child (GTK_BIN (button));
+	if (child)
+		gtk_container_remove (GTK_CONTAINER (button), child);
 
   	if (gtk_stock_lookup (stock_id, &item))
     	{
@@ -232,7 +233,7 @@ anjuta_util_dialog_add_button (GtkDialog *dialog, const gchar* text,
 	button = anjuta_util_button_new_with_stock_image (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 
 	gtk_widget_show (button);
 
@@ -435,7 +436,7 @@ anjuta_util_dialog_input (GtkWindow *parent, const gchar *prompt,
 										  GTK_STOCK_OK, GTK_RESPONSE_OK,
 										  NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	dialog_vbox = GTK_DIALOG (dialog)->vbox;
+	dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, -1);
 	gtk_widget_show (dialog_vbox);
 	
@@ -983,7 +984,7 @@ anjuta_util_user_terminal (void)
 	}
 
 	/* Try xterm */
-	g_warning (_("Cannot find a terminal, using "
+	g_warning (_("Cannot find a terminal; using "
 			"xterm, even if it may not work"));
 	terminal = g_strdup ("xterm");
 
@@ -1687,9 +1688,9 @@ anjuta_util_help_display (GtkWidget   *parent,
 
 	if (uri == NULL)
 	{
-		anjuta_util_dialog_error (GTK_WINDOW (parent), _("Unable to display help. Please make sure Anjuta "
-								  "documentation package is install. It can be downloaded "
-								  "from http://anjuta.org"));
+		anjuta_util_dialog_error (GTK_WINDOW (parent), _("Unable to display help. Please make sure the Anjuta "
+								  "documentation package is installed. It can be downloaded "
+								  "from http://anjuta.org."));
 
 		return;
 	}
@@ -2192,3 +2193,30 @@ anjuta_util_builder_get_objects (GtkBuilder *builder, const gchar *first_widget,
 
 	return !missing;
 }
+
+/**
+ * anjuta_utils_drop_get_files:
+ * @selection_data: the #GtkSelectionData from drag_data_received
+ * @info: the info from drag_data_received
+ *
+ * Create a list of valid uri's from a uri-list drop.
+ * 
+ * Return value: a list of GFiles
+ */
+GSList*
+anjuta_utils_drop_get_files (GtkSelectionData *selection_data)
+{
+	gchar **uris;
+	gint i;
+	GSList* files = NULL;
+
+	uris = g_uri_list_extract_uris ((gchar *) gtk_selection_data_get_data (selection_data));
+
+	for (i = 0; uris[i] != NULL; i++)
+	{
+		GFile* file = g_file_new_for_commandline_arg (uris[0]);
+		files = g_slist_append(files, file);
+	}
+
+	return files;
+}
