@@ -290,6 +290,23 @@ escape_label (const gchar *str)
 	return g_string_free (ret, FALSE);
 }
 
+static gchar*
+shell_quotef (const gchar *format,...)
+{
+	va_list args;
+	gchar *str;
+	gchar *quoted_str;
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	quoted_str = g_shell_quote (str);
+	g_free (str);
+
+	return quoted_str;
+}
+
 /* Indicator locations reported by the build */
 
 static BuildIndicatorLocation*
@@ -567,6 +584,7 @@ build_regex_load ()
 		
 		patterns_list = g_list_prepend (patterns_list, pattern);
 	}
+	fclose (fp);
 	patterns_list = g_list_reverse (patterns_list);
 }
 
@@ -1333,7 +1351,7 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 		ianjuta_message_view_buffer_append (context->message_view, command, NULL);
 		ianjuta_message_view_buffer_append (context->message_view, "\n", NULL);
 		g_free (command);
-	
+
 		anjuta_launcher_execute_v (context->launcher,
 		    context->program->work_dir,
 		    context->program->argv,
@@ -1799,7 +1817,7 @@ build_compile_file (BasicAutotoolsPlugin *plugin, const gchar *filename)
 		*/
 		GtkWindow *window;
 		window = GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell);
-		anjuta_util_dialog_error (window, _("Can not compile \"%s\": No compile rule defined for this file type."), filename);
+		anjuta_util_dialog_error (window, _("Cannot compile \"%s\": No compile rule defined for this file type."), filename);
 	}
 	
 	return context;
@@ -1853,14 +1871,18 @@ build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const g
 	BuildContext *context;
 	BuildProgram *prog;
 	BuildConfigureAndBuild *pack = g_new0 (BuildConfigureAndBuild, 1);
+	gchar *quote;
 
+	quote = shell_quotef ("%s%s%s",
+		       	plugin->project_root_dir,
+		       	G_DIR_SEPARATOR_S,
+			CHOOSE_COMMAND (plugin, CONFIGURE));
 	
 	prog = build_program_new_with_command (dirname,
-										   "%s%s%s %s",
-										   plugin->project_root_dir,
-										   G_DIR_SEPARATOR_S,
-										   CHOOSE_COMMAND (plugin, CONFIGURE),
+										   "%s %s",
+										   quote,
 										   args);
+	g_free (quote);
 	pack->args = NULL;
 	pack->func = func;
 	pack->name = g_strdup (name);
@@ -1905,13 +1927,18 @@ build_configure_after_autogen (GObject *sender,
 			{
 				/* configure has not be run, run it */
 				BuildProgram *prog;
+				gchar *quote;
+
+				quote = shell_quotef ("%s%s%s",
+					     	plugin->project_root_dir,
+					       	G_DIR_SEPARATOR_S,
+					       	CHOOSE_COMMAND (plugin, CONFIGURE));
 
 				prog = build_program_new_with_command (context->program->work_dir,
-													   "%s%s%s %s",
-													   plugin->project_root_dir,
-													   G_DIR_SEPARATOR_S,
-													   CHOOSE_COMMAND (plugin, CONFIGURE),
+													   "%s %s",
+													   quote,
 													   pack != NULL ? pack->args : NULL);
+				g_free (quote);
 				build_program_set_callback (prog, build_project_configured, pack);
 		
 				build_set_command_in_context (context, prog);
@@ -1925,7 +1952,7 @@ build_configure_after_autogen (GObject *sender,
 			
 			return;
 		}
-		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell), _("Can not configure project: Missing configure script in %s."), plugin->project_root_dir);
+		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell), _("Cannot configure project: Missing configure script in %s."), plugin->project_root_dir);
 	}
 
 	if (pack)
@@ -1946,12 +1973,17 @@ build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gc
 	
 	if (directory_has_file (plugin->project_root_dir, "autogen.sh"))
 	{
+		gchar *quote;
+
+		quote = shell_quotef ("%s%s%s",
+				plugin->project_root_dir,
+			       	G_DIR_SEPARATOR_S,
+			       	CHOOSE_COMMAND (plugin, GENERATE));
 		prog = build_program_new_with_command (dirname,
-											   "%s%s%s %s",
-											   plugin->project_root_dir,
-											   G_DIR_SEPARATOR_S,
-											   CHOOSE_COMMAND (plugin, GENERATE),
+											   "%s %s",
+											   quote,
 											   args);
+		g_free (quote);
 	}
 	else
 	{
@@ -2090,18 +2122,24 @@ static const gchar*
 build_get_uri_configuration (BasicAutotoolsPlugin *plugin, const gchar *uri)
 {
 	BuildConfiguration *cfg;
-	
+	BuildConfiguration *uri_cfg;
+	gsize uri_len = 0;
+
+	/* Check all configurations as other configuration directories are
+	 * normally child of default configuration directory */	
 	for (cfg = build_configuration_list_get_first (plugin->configurations); cfg != NULL; cfg = build_configuration_next (cfg))
 	{
 		const gchar *root = build_configuration_list_get_build_uri  (plugin->configurations, cfg);
+		gsize len = strlen (root);
 
-		if (strncmp (uri, root, strlen (root)) == 0)
+		if ((len > uri_len) && (strncmp (uri, root, len) == 0))
 		{
-			return build_configuration_get_name (cfg);
+			uri_cfg = cfg;
+			uri_len = len;
 		}
 	}
 
-	return NULL;
+	return uri_len == 0 ? NULL : build_configuration_get_name (uri_cfg);
 }
 
 
@@ -2413,7 +2451,7 @@ static GtkActionEntry build_actions[] =
 	},
 	{
 		"ActionBuildConfigure", NULL,
-		N_("C_onfigure Project..."), NULL,
+		N_("C_onfigure Project…"), NULL,
 		N_("Configure project"),
 		G_CALLBACK (on_configure_project)
 	},
@@ -2607,16 +2645,16 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (bb_plugin)->shell, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildBuildProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildInstallProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildCleanProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildDistribution");
-	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildConfigure");
 	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
@@ -3052,8 +3090,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 		filename = g_file_get_path(file);
 		g_object_unref (file);
 		g_return_if_fail (filename != NULL);
-		ba_plugin->current_editor_filename = anjuta_util_get_real_path (filename);
-		g_free (filename);
+		ba_plugin->current_editor_filename = filename;
 		update_module_ui (ba_plugin);
 	}
 	g_idle_add (on_update_indicators_idle, plugin);
