@@ -33,8 +33,8 @@
 
 /*---------------------------------------------------------------------------*/
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-run-program.ui"
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-run-program.glade"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-run-program.xml"
+#define BUILDER_FILE PACKAGE_DATA_DIR"/glade/anjuta-run-program.ui"
 
 #define PARAMETERS_DIALOG "parameters_dialog"
 #define TERMINAL_CHECK_BUTTON "parameter_run_in_term_check"
@@ -237,7 +237,7 @@ save_dialog_data (RunDialog* dlg)
 	RunProgramPlugin *plugin = dlg->plugin;
 
 	/* Save arguments */
-	arg = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (dlg->args)->child));
+	arg = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dlg->args))));
 	if (arg != NULL)
 	{
 		find = g_list_find_custom(plugin->recent_args, arg, (GCompareFunc)strcmp);
@@ -250,7 +250,7 @@ save_dialog_data (RunDialog* dlg)
 	}	
 
 	/* Save target */
-	filename = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (dlg->target)->child));
+	filename = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dlg->target))));
 	if ((filename != NULL) && (*filename != '\0'))
 	{
 		GFile *file;
@@ -313,7 +313,7 @@ on_select_target (RunDialog* dlg)
 	{
 		gchar* filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (sel_dlg));
 
-		gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dlg->target)->child), filename);
+		gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dlg->target))), filename);
 		g_free (filename);
 	}		
 	gtk_widget_destroy (GTK_WIDGET (sel_dlg));
@@ -469,6 +469,29 @@ on_environment_remove_button (GtkButton *button, RunDialog *dlg)
 	}
 }
 
+static gboolean
+move_to_environment_value (gpointer data)
+{
+	GtkTreeView *view = GTK_TREE_VIEW (data);
+	GtkTreeSelection* sel;
+	GtkTreeModel *model;
+	GtkTreeIter iter;	
+	GtkTreeViewColumn *column;
+
+	sel = gtk_tree_view_get_selection (view);
+	if (gtk_tree_selection_get_selected (sel, &model, &iter))
+	{
+		GtkTreePath *path;
+		
+		path = gtk_tree_model_get_path (model, &iter);
+		column = gtk_tree_view_get_column (view, ENV_VALUE_COLUMN);
+		gtk_tree_view_set_cursor (view, path, column, TRUE);
+		gtk_tree_path_free (path);
+	}
+
+	return FALSE;
+}
+
 static void
 on_environment_variable_edited (GtkCellRendererText *cell,
 						  gchar *path,
@@ -484,7 +507,7 @@ on_environment_variable_edited (GtkCellRendererText *cell,
 	text = g_strstrip (text);
 	
 	model = GTK_LIST_STORE (gtk_tree_view_get_model (view));
-	
+
 	valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (model), &iter, path);
 	if (valid)
 	{
@@ -500,9 +523,6 @@ on_environment_variable_edited (GtkCellRendererText *cell,
 		
 		if (strcmp(name, text) != 0)
 		{
-			GtkTreeSelection* sel;
-			GtkTreePath *path;
-			GtkTreeViewColumn *column;
 			
 			if (def_value != NULL)
 			{
@@ -541,16 +561,9 @@ on_environment_variable_edited (GtkCellRendererText *cell,
 				{
 					gtk_list_store_set (model, &iter, ENV_NAME_COLUMN, text,
 										-1);
-					niter = iter;
 				}
 			}
-			sel = gtk_tree_view_get_selection (view);
-			gtk_tree_selection_select_iter (sel, &niter);
-			path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &niter);
-			column = gtk_tree_view_get_column (view, ENV_VALUE_COLUMN);
-			gtk_tree_view_scroll_to_cell (view, path, column, FALSE, 0, 0);
-			gtk_tree_view_set_cursor (view, path, column ,TRUE);
-			gtk_tree_path_free (path);
+			g_idle_add (move_to_environment_value, view);
 		}
 		g_free (name);
 		g_free (def_value);
@@ -583,8 +596,9 @@ on_environment_value_edited (GtkCellRendererText *cell,
 static RunDialog*
 run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkWindow *parent;
+	GtkWidget *child;
 	GtkCellRenderer *renderer;	
 	GtkTreeModel* model;
 	GtkTreeViewColumn *column;
@@ -592,48 +606,52 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 	GObject *button;
 	GValue value = {0,};
 	const gchar *project_root_uri;
+	GError* error = NULL;
 	
 	parent = GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell);
-	gxml = glade_xml_new (GLADE_FILE, PARAMETERS_DIALOG, NULL);
-	if (gxml == NULL)
+	bxml = gtk_builder_new ();
+
+	if (!gtk_builder_add_from_file (bxml, BUILDER_FILE, &error))
 	{
-		anjuta_util_dialog_error(parent, _("Missing file %s"), GLADE_FILE);
+		g_warning ("Couldn't load builder file: %s", error->message);
+		anjuta_util_dialog_error(parent, _("Missing file %s"), BUILDER_FILE);
+		g_error_free (error);
 		return NULL;
 	}
 	
 	dlg->plugin = plugin;
 		
-	dlg->win = glade_xml_get_widget (gxml, PARAMETERS_DIALOG);
-	dlg->term = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gxml, TERMINAL_CHECK_BUTTON));
-	dlg->args = GTK_COMBO_BOX (glade_xml_get_widget (gxml, PARAMETER_COMBO));
-	dlg->target = GTK_COMBO_BOX (glade_xml_get_widget (gxml, TARGET_COMBO));
-	dlg->vars = GTK_TREE_VIEW (glade_xml_get_widget (gxml, VAR_TREEVIEW));
-	dlg->dirs = GTK_FILE_CHOOSER (glade_xml_get_widget (gxml, DIR_CHOOSER));
-	dlg->remove_button = glade_xml_get_widget (gxml, REMOVE_VAR_BUTTON);
-	dlg->edit_button = glade_xml_get_widget (gxml, EDIT_VAR_BUTTON);
+	dlg->win = GTK_WIDGET (gtk_builder_get_object (bxml, PARAMETERS_DIALOG));
+	dlg->term = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TERMINAL_CHECK_BUTTON));
+	dlg->args = GTK_COMBO_BOX (gtk_builder_get_object (bxml, PARAMETER_COMBO));
+	dlg->target = GTK_COMBO_BOX (gtk_builder_get_object (bxml, TARGET_COMBO));
+	dlg->vars = GTK_TREE_VIEW (gtk_builder_get_object (bxml, VAR_TREEVIEW));
+	dlg->dirs = GTK_FILE_CHOOSER (gtk_builder_get_object (bxml, DIR_CHOOSER));
+	dlg->remove_button = GTK_WIDGET (gtk_builder_get_object (bxml, REMOVE_VAR_BUTTON));
+	dlg->edit_button = GTK_WIDGET (gtk_builder_get_object (bxml, EDIT_VAR_BUTTON));
 
 	/* Connect signals */	
-	button = G_OBJECT (glade_xml_get_widget (gxml, TARGET_BUTTON));
+	button = gtk_builder_get_object (bxml, TARGET_BUTTON);
 	g_signal_connect_swapped (button, "clicked", G_CALLBACK (on_select_target), dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, ADD_VAR_BUTTON));
+	button = gtk_builder_get_object (bxml, ADD_VAR_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_environment_add_button), dlg->vars);
-	button = G_OBJECT (glade_xml_get_widget (gxml, EDIT_VAR_BUTTON));
+	button = gtk_builder_get_object (bxml, EDIT_VAR_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_environment_edit_button), dlg->vars);
-	button = G_OBJECT (glade_xml_get_widget (gxml, REMOVE_VAR_BUTTON));
+	button = gtk_builder_get_object (bxml, REMOVE_VAR_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_environment_remove_button), dlg);
 	selection = gtk_tree_view_get_selection (dlg->vars);
 	g_signal_connect (selection, "changed", G_CALLBACK (on_environment_selection_changed), dlg);
 	
-	g_object_unref (gxml);
+	g_object_unref (bxml);
 
 	/* Fill parameter combo box */
-	model = GTK_TREE_MODEL (gtk_list_store_new (1, GTK_TYPE_STRING));
+	model = GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING));
 	gtk_combo_box_set_model (dlg->args, model);
 	gtk_combo_box_entry_set_text_column( GTK_COMBO_BOX_ENTRY(dlg->args), 0);
 	g_list_foreach (plugin->recent_args, on_add_string_in_model, model);
 	if (plugin->recent_args != NULL)
 	{
-		gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dlg->args)->child), (const char *)plugin->recent_args->data);
+		gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dlg->args))), (const char *)plugin->recent_args->data);
 	}
 	g_object_unref (model);
 
@@ -642,12 +660,12 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 	if (plugin->recent_dirs != NULL) gtk_file_chooser_set_uri (dlg->dirs, (const char *)plugin->recent_dirs->data);
 	
 	/* Fill target combo box */
-	model = GTK_TREE_MODEL (gtk_list_store_new (1, GTK_TYPE_STRING));
+	model = GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING));
 	gtk_combo_box_set_model (dlg->target, model);
 	gtk_combo_box_entry_set_text_column( GTK_COMBO_BOX_ENTRY(dlg->target), 0);
 	g_list_foreach (plugin->recent_target, on_add_uri_in_model, model);
 
-    anjuta_shell_get_value (ANJUTA_PLUGIN (plugin)->shell, "project_root_uri", &value, NULL);
+    anjuta_shell_get_value (ANJUTA_PLUGIN (plugin)->shell, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, &value, NULL);
 	project_root_uri = G_VALUE_HOLDS_STRING (&value) ? g_value_get_string (&value) : NULL;
 	if (project_root_uri != NULL)
 	{
@@ -687,13 +705,15 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 		 * new project created by the wizard without any change */
 		if (plugin->recent_dirs == NULL) gtk_file_chooser_set_uri (dlg->dirs, project_root_uri);
 	}
+
+	child = gtk_bin_get_child (GTK_BIN (dlg->target));
 	
 	if (plugin->recent_target != NULL)
 	{
 		gchar *local;
 		
 		local = anjuta_util_get_local_path_from_uri ((const char *)plugin->recent_target->data);
-		gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dlg->target)->child), local);
+		gtk_entry_set_text (GTK_ENTRY (child), local);
 		g_free (local);
 	}
 	else
@@ -709,7 +729,7 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 			gtk_tree_model_get (model, &iter,
 								0, &default_target,
 								-1);
-			gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dlg->target)->child), default_target);
+			gtk_entry_set_text (GTK_ENTRY (child), default_target);
 			g_free (default_target);
 		}
 	}
@@ -760,7 +780,7 @@ run_parameters_dialog_or_try_execute (RunProgramPlugin *plugin, gboolean try_run
 	gint response;
 	
 	run_dialog_init (&dlg, plugin);
-	const char *target = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (dlg.target)->child));
+	const char *target = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dlg.target))));
 	if (try_run && target && *target)
 	{
 		save_dialog_data (&dlg);
