@@ -83,7 +83,7 @@ ATPEnumType output_type_list[] = {
  {ATP_TOUT_NEW_PANE, N_("New message pane")},
  {ATP_TOUT_NEW_BUFFER, N_("New buffer")},
  {ATP_TOUT_REPLACE_BUFFER, N_("Replace buffer")},
- {ATP_TOUT_INSERT_BUFFER, N_("Insert in buffer")},
+ {ATP_TOUT_INSERT_BUFFER, N_("Insert into buffer")},
  {ATP_TOUT_APPEND_BUFFER, N_("Append to buffer")},
  {ATP_TOUT_REPLACE_SELECTION, N_("Replace selection")},
  /* Translators: Checkbox if a dialog should be shown after some operation finishes, so translate as "to pop up a dialog" */
